Kali-linux :arping命令

Kali-linux :arping命令ARP协议是“AddressResolutionProtocol”(地址解析协议)的缩写。在同一以太网中,通过地址解析协议,源主机可以通过目的主机的IP地址获得目的主机的MAC地址。arping程序就是完成上述过程的程序。arping,用来向局域网内的其它主机发送ARP请求的指令,它可以用来测试局域网内的某个IP是否已被使用。root@pgg:/home/pgg#arping–helpARPing2.21,byThomasHabetsthomas@habets.seusage:

大家好,又见面了,我是你们的朋友全栈君。

ARP协议是“Address Resolution Protocol”(地址解析协议)的缩写。在同一以太网中,通过地址解析协议,源主机可以通过目的主机的IP地址获得目的主机的MAC地址。arping程序就是完成上述过程的程序。

arping,用来向局域网内的其它主机发送ARP请求的指令,它可以用来测试局域网内的某个IP是否已被使用。

root@pgg:/home/pgg# arping --help

ARPing 2.21, by Thomas Habets thomas@habets.se
usage: arping [ -0aAbdDeFpPqrRuUv ] [ -w ] [ -W ] [ -S <host/ip> ]
[ -T <host/ip ] [ -s ] [ -t ] [ -c ]
[ -C ] [ -i ] [ -m ] [ -g ]
[ -V ] [ -Q ] <host/ip/MAC | -B>

Options:

-0     Use this option to ping with source IP address 0.0.0.0. Use this
       when you haven't configured your interface yet.  Note that  this
       may  get  the  MAC-ping  unanswered.   This  is  an alias for -S
       0.0.0.0.
-a     Audiable ping.
-A     Only count addresses matching  requested  address  (This  *WILL*
       break  most things you do. Only useful if you are arpinging many
       hosts at once. See arping-scan-net.sh for an example).
-b     Like -0 but source broadcast source  address  (255.255.255.255).
       Note that this may get the arping unanswered since it's not nor-
       mal behavior for a host.
-B     Use instead of host if you want to address 255.255.255.255.
-c count
       Only send count requests.
-C count
       Only wait for this many replies, regardless of -c and -w.
-d     Find duplicate replies. Exit with 1 if there are answers from
       two different MAC addresses.
-D     Display answers as exclamation points and missing packets as dots.
-e     Like -a but beep when there is no reply.
-F     Don't try to be smart about the interface name.  (even  if  this
       switch is not given, -i overrides smartness)
-g group
       setgid() to this group instead of the nobody group.
-h     Displays a help message and exits.
-i interface
       Use the specified interface.
-m type
       Type of timestamp to use for incoming packets. Use -vv when
       pinging to list available ones.
-q     Does not display messages, except error messages.
-Q pri 802.1p priority to set. Should be used with 802.1Q (-V).
       Defaults to 0.
-r     Raw output: only the MAC/IP address is displayed for each reply.
-R     Raw output: Like -r but shows "the other one", can  be  combined
       with -r.
-s MAC Set source MAC address. You may need to use -p with this.
-S IP  Like  -b and -0 but with set source address.  Note that this may
       get the arping unanswered if the target does not have routing to
       the  IP.  If you don't own the IP you are using, you may need to
       turn on promiscious mode on the interface (with -p).  With  this
       switch  you can find out what IP-address a host has without tak-
       ing an IP-address yourself.
-t MAC Set target MAC address to use when pinging IP address.
-T IP  Use -T as target address when pinging MACs that won't respond to
       a broadcast ping but perhaps to a directed broadcast.
       Example:
       To check the address of MAC-A, use knowledge of MAC-B and  IP-B.
       $ arping -S <IP-B> -s <MAC-B> -p <MAC-A>
-p     Turn  on  promiscious  mode  on interface, use this if you don't
       "own" the MAC address you are using.
-P     Send ARP replies instead of requests. Useful with -U.
-u     Show index=received/sent instead  of  just  index=received  when
       pinging MACs.
-U     Send unsolicited ARP.
-v     Verbose output. Use twice for more messages.
-V num 802.1Q tag to add. Defaults to no VLAN tag.
-w sec Specify a timeout before ping exits regardless of how many packets have been sent or received.
-W sec Time to wait between pings.

Report bugs to: thomas@habets.se
Arping home page: http://www.habets.pp.se/synscan/
Development repo: http://github.com/ThomasHabets/arping

版权声明:本文内容由互联网用户自发贡献,该文观点仅代表作者本人。本站仅提供信息存储空间服务,不拥有所有权,不承担相关法律责任。如发现本站有涉嫌侵权/违法违规的内容, 请发送邮件至 举报,一经查实,本站将立刻删除。

发布者:全栈程序员-站长,转载请注明出处:https://javaforall.net/139698.html原文链接:https://javaforall.net

赞 (0)
全栈程序员-站长的头像全栈程序员-站长


相关推荐

  • java List去除重复数据的五种方式

    java List去除重复数据的五种方式以下介绍五种-不同的方法去除Java中ArrayList中的重复数据1.使用LinkedHashSet删除arraylist中的重复数据LinkedHashSet是在一个ArrayList删除重复数据的最佳方法。LinkedHashSet在内部完成两件事:删除重复数据 保持添加到其中的数据的顺序Java示例使用LinkedHashSet删除arraylist中的重复项。在…

    2022年5月26日
  • 深入浅出Python机器学习3——K最近邻算法

    深入浅出Python机器学习3——K最近邻算法K最近邻的算法的原理;在分类任务中的应用;在回归分析中的应用;使用K最近邻算法对酒的分类进行分类。

    2022年10月8日
  • 蓝桥杯集锦05(python3)

    蓝桥杯集锦05(python3)

    2021年4月18日
  • Android studio 升级报错No toolchains found in the NDK toolchains folder for ABI with prefix

    Android studio 升级报错No toolchains found in the NDK toolchains folder for ABI with prefix

    2021年9月30日
  • eclipse自动补全设置_eclipse补全设置

    eclipse自动补全设置_eclipse补全设置Eclipse版本问题描述自动补全显示顺序不尽人意,如下:输入equals使用自动补全后,显然并不是我们希望使用的方法。解决方法1进入Windows选项卡下的Perferences,搜索ContentAssist,找到Java选项卡下的ContentAssist,选择Advanced选项卡。将其中内容配置为(即,将上下两部分的JavaProposals(Task-Focused)取消勾选,将JavaProposals勾选);之后就可以开心的使用自动补全啦!解决方法2这是

    2022年10月15日
  • 数据挖掘——关联规则挖掘

    数据挖掘——关联规则挖掘《数据挖掘》国防科技大学《数据挖掘》青岛大学数据挖掘之关联规则挖掘关联规则挖掘(AssociationRuleMining)最早是由Agrawal等人提出。最初的动机是解决购物篮分析(BasketAnalysis)问题,目的是发现交易数据库(TransactionDatabase)中不同商品之间的联系规则。定义关联规则是描述在一个交易中物品之间同时出现的规律的知识模式,更确切的说,关联规则是通过量化的数字描述物品X的出现对物品Y的出现有多大的影响。关联分析associationana

    2022年7月17日

发表回复

您的邮箱地址不会被公开。 必填项已用 * 标注

关注全栈程序员社区公众号